Learn R Programming

filesstrings (version 1.1.0)

filesstrings-defunct: Defunct functions

Description

These functions have been made defunct, mostly because the naming style of the package has been changed. To figure out which function to run instead, run the defunct function of interest and you'll get an error message telling you which function to use instead.

Arguments