powered by
These are faster implementations of procedures that could very easily be done with base::sapply.
str_list_nth_elems(char_list, n)num_list_nth_elems(num_list, n)
num_list_nth_elems(num_list, n)
A list of character vectors.
The index of the element that you want from each vector.
A list of numeric vectors.
A list.
# NOT RUN { str_list_nth_elems(list(c("a", "b", "c"), c("d", "f", "a")), 2) num_list_nth_elems(list(1:5, 0:2), 4) # }
Run the code above in your browser using DataLab