StrAfterNth: Text before or after \(n\)th occurrence of pattern.
Description
Extract the part of a string which is before or after the \(n\)th
occurrence of a specified pattern, vectorised over the string. One can also
choose \(n\) to be the last occurrence of the pattern. See argument
n.
Usage
StrAfterNth(strings, pattern, n = 1)
StrBeforeNth(strings, pattern, n = 1)
Arguments
strings
A character vector.
pattern
A regular expression.
n
A natural number to identify the \(n\)th occurrence (defaults to
first (n = 1)). This can be negatively indexed, so if you wish to select
the last occurrence, you need n = -1, for the second-last, you
need n = -2 and so on.