powered by
Given the names of (potential) directories, create the ones that do not already exist.
create_dirs(dirs)
The name of the directories, specified via relative or absolute paths.
Invisibly, a vector with a TRUE for each time a directory was actually created and a FALSE otherwise.
TRUE
FALSE
# NOT RUN { setwd(tempdir()) create_dirs(c("mydir", "yourdir")) remove_dirs(c("mydir", "yourdir")) # }
Run the code above in your browser using DataLab